Generated by Cython 0.15.1 on Thu Jan 17 21:03:40 2013

Raw output: cWriterow.c

     1: def cWriterow(self, record):

    /* "cWriterow.pyx":1
     * def cWriterow(self, record):             # <<<<<<<<<<<<<<
     *     cdef int varType
     *     cdef float sysmis
     */

    static PyObject *__pyx_pf_9cWriterow_cWriterow(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
    static PyMethodDef __pyx_mdef_9cWriterow_cWriterow = {__Pyx_NAMESTR("cWriterow"), (PyCFunction)__pyx_pf_9cWriterow_cWriterow, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)};
    static PyObject *__pyx_pf_9cWriterow_cWriterow(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
      PyObject *__pyx_v_self = 0;
      PyObject *__pyx_v_record = 0;
      int __pyx_v_varType;
      float __pyx_v_sysmis;
      Py_ssize_t __pyx_v_i;
      PyObject *__pyx_v_varName = NULL;
      double __pyx_v_numValue;
      PyObject *__pyx_v_value = NULL;
      PyObject *__pyx_v_valueX = NULL;
      PyObject *__pyx_v_strValue = NULL;
      PyObject *__pyx_r = NULL;
      static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__self,&__pyx_n_s__record,0};
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("cWriterow");
      __pyx_self = __pyx_self;
      {
        PyObject* values[2] = {0,0};
        if (unlikely(__pyx_kwds)) {
          Py_ssize_t kw_args;
          switch (PyTuple_GET_SIZE(__pyx_args)) {
            case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
            case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
            case  0: break;
            default: goto __pyx_L5_argtuple_error;
          }
          kw_args = PyDict_Size(__pyx_kwds);
          switch (PyTuple_GET_SIZE(__pyx_args)) {
            case  0:
            values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__self);
            if (likely(values[0])) kw_args--;
            else goto __pyx_L5_argtuple_error;
            case  1:
            values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__record);
            if (likely(values[1])) kw_args--;
            else {
              __Pyx_RaiseArgtupleInvalid("cWriterow", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
            }
          }
          if (unlikely(kw_args > 0)) {
            if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, PyTuple_GET_SIZE(__pyx_args), "cWriterow") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
          }
        } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
          goto __pyx_L5_argtuple_error;
        } else {
          values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
          values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        }
        __pyx_v_self = values[0];
        __pyx_v_record = values[1];
      }
      goto __pyx_L4_argument_unpacking_done;
      __pyx_L5_argtuple_error:;
      __Pyx_RaiseArgtupleInvalid("cWriterow", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __pyx_L3_error:;
      __Pyx_AddTraceback("cWriterow.cWriterow", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __Pyx_RefNannyFinishContext();
      return NULL;
      __pyx_L4_argument_unpacking_done:;

      /* "cWriterow.pyx":1
     * def cWriterow(self, record):             # <<<<<<<<<<<<<<
     *     cdef int varType
     *     cdef float sysmis
     */
      __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_9cWriterow_cWriterow, NULL, __pyx_n_s__cWriterow); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      if (PyObject_SetAttr(__pyx_m, __pyx_n_s__cWriterow, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

     2:     cdef int varType

     3:     cdef float sysmis

     4:     cdef Py_ssize_t i

     5:     sysmis = self.sysmis_

      /* "cWriterow.pyx":5
     *     cdef float sysmis
     *     cdef Py_ssize_t i
     *     sysmis = self.sysmis_             # <<<<<<<<<<<<<<
     *     for i, varName in enumerate(self.varNames):
     *         varName = self.varNames[i]
     */
      __pyx_t_1 = PyObject_GetAttr(__pyx_v_self, __pyx_n_s__sysmis_); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 5; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_2 == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 5; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_sysmis = __pyx_t_2;

     6:     for i, varName in enumerate(self.varNames):

      /* "cWriterow.pyx":6
     *     cdef Py_ssize_t i
     *     sysmis = self.sysmis_
     *     for i, varName in enumerate(self.varNames):             # <<<<<<<<<<<<<<
     *         varName = self.varNames[i]
     *         varType = self.varTypes[varName]
     */
      __pyx_t_3 = 0;
      __pyx_t_1 = PyObject_GetAttr(__pyx_v_self, __pyx_n_s__varNames); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 6; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      if (PyList_CheckExact(__pyx_t_1) || PyTuple_CheckExact(__pyx_t_1)) {
        __pyx_t_4 = __pyx_t_1; __Pyx_INCREF(__pyx_t_4); __pyx_t_5 = 0;
        __pyx_t_6 = NULL;
      } else {
        __pyx_t_5 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 6; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = Py_TYPE(__pyx_t_4)->tp_iternext;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      for (;;) {
        if (PyList_CheckExact(__pyx_t_4)) {
          if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_4)) break;
          __pyx_t_1 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++;
        } else if (PyTuple_CheckExact(__pyx_t_4)) {
          if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
          __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++;
        } else {
          __pyx_t_1 = __pyx_t_6(__pyx_t_4);
          if (unlikely(!__pyx_t_1)) {
            if (PyErr_Occurred()) {
              if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
              else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 6; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_XDECREF(__pyx_v_varName);
        __pyx_v_varName = __pyx_t_1;
        __pyx_t_1 = 0;
        __pyx_v_i = __pyx_t_3;
        __pyx_t_3 = (__pyx_t_3 + 1);

     7:         varName = self.varNames[i]

        /* "cWriterow.pyx":7
     *     sysmis = self.sysmis_
     *     for i, varName in enumerate(self.varNames):
     *         varName = self.varNames[i]             # <<<<<<<<<<<<<<
     *         varType = self.varTypes[varName]
     *         if varType == 0:
     */
        __pyx_t_1 = PyObject_GetAttr(__pyx_v_self, __pyx_n_s__varNames); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 7; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_1, __pyx_v_i, sizeof(Py_ssize_t), PyInt_FromSsize_t); if (!__pyx_t_7) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 7; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_v_varName);
        __pyx_v_varName = __pyx_t_7;
        __pyx_t_7 = 0;

     8:         varType = self.varTypes[varName]

        /* "cWriterow.pyx":8
     *     for i, varName in enumerate(self.varNames):
     *         varName = self.varNames[i]
     *         varType = self.varTypes[varName]             # <<<<<<<<<<<<<<
     *         if varType == 0:
     *             try:
     */
        __pyx_t_7 = PyObject_GetAttr(__pyx_v_self, __pyx_n_s__varTypes); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 8; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_1 = PyObject_GetItem(__pyx_t_7, __pyx_v_varName); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 8; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_8 = __Pyx_PyInt_AsInt(__pyx_t_1); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 8; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_varType = __pyx_t_8;

     9:         if varType == 0:

        /* "cWriterow.pyx":9
     *         varName = self.varNames[i]
     *         varType = self.varTypes[varName]
     *         if varType == 0:             # <<<<<<<<<<<<<<
     *             try:
     *                 numValue = float(record[i])
     */
        __pyx_t_9 = (__pyx_v_varType == 0);
        if (__pyx_t_9) {

     10:             try:

          /* "cWriterow.pyx":10
     *         varType = self.varTypes[varName]
     *         if varType == 0:
     *             try:             # <<<<<<<<<<<<<<
     *                 numValue = float(record[i])
     *             except ValueError:
     */
          {
            __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
            __Pyx_XGOTREF(__pyx_t_10);
            __Pyx_XGOTREF(__pyx_t_11);
            __Pyx_XGOTREF(__pyx_t_12);
            /*try:*/ {

     11:                 numValue = float(record[i])

              /* "cWriterow.pyx":11
     *         if varType == 0:
     *             try:
     *                 numValue = float(record[i])             # <<<<<<<<<<<<<<
     *             except ValueError:
     *                 numValue = sysmis
     */
              __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_record, __pyx_v_i, sizeof(Py_ssize_t), PyInt_FromSsize_t); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 11; __pyx_clineno = __LINE__; goto __pyx_L9_error;}
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_13 = __Pyx_PyObject_AsDouble(__pyx_t_1); if (unlikely(__pyx_t_13 == ((double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 11; __pyx_clineno = __LINE__; goto __pyx_L9_error;}
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __pyx_v_numValue = __pyx_t_13;
            }
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            goto __pyx_L16_try_end;
            __pyx_L9_error:;
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

     12:             except ValueError:

            /* "cWriterow.pyx":12
     *             try:
     *                 numValue = float(record[i])
     *             except ValueError:             # <<<<<<<<<<<<<<
     *                 numValue = sysmis
     *             except TypeError:
     */
            __pyx_t_8 = PyErr_ExceptionMatches(__pyx_builtin_ValueError);
            if (__pyx_t_8) {
              __Pyx_AddTraceback("cWriterow.cWriterow", __pyx_clineno, __pyx_lineno, __pyx_filename);
              if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_7, &__pyx_t_14) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 12; __pyx_clineno = __LINE__; goto __pyx_L11_except_error;}
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_GOTREF(__pyx_t_14);

     13:                 numValue = sysmis

              /* "cWriterow.pyx":13
     *                 numValue = float(record[i])
     *             except ValueError:
     *                 numValue = sysmis             # <<<<<<<<<<<<<<
     *             except TypeError:
     *                 numValue = sysmis
     */
              __pyx_v_numValue = __pyx_v_sysmis;
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              goto __pyx_L10_exception_handled;
            }

     14:             except TypeError:

            /* "cWriterow.pyx":14
     *             except ValueError:
     *                 numValue = sysmis
     *             except TypeError:             # <<<<<<<<<<<<<<
     *                 numValue = sysmis
     *             record[i] = numValue
     */
            __pyx_t_8 = PyErr_ExceptionMatches(__pyx_builtin_TypeError);
            if (__pyx_t_8) {
              __Pyx_AddTraceback("cWriterow.cWriterow", __pyx_clineno, __pyx_lineno, __pyx_filename);
              if (__Pyx_GetException(&__pyx_t_14, &__pyx_t_7, &__pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L11_except_error;}
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_GOTREF(__pyx_t_1);

     15:                 numValue = sysmis

              /* "cWriterow.pyx":15
     *                 numValue = sysmis
     *             except TypeError:
     *                 numValue = sysmis             # <<<<<<<<<<<<<<
     *             record[i] = numValue
     *         else:
     */
              __pyx_v_numValue = __pyx_v_sysmis;
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              goto __pyx_L10_exception_handled;
            }
            __pyx_L11_except_error:;
            __Pyx_XGIVEREF(__pyx_t_10);
            __Pyx_XGIVEREF(__pyx_t_11);
            __Pyx_XGIVEREF(__pyx_t_12);
            __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
            goto __pyx_L1_error;
            __pyx_L10_exception_handled:;
            __Pyx_XGIVEREF(__pyx_t_10);
            __Pyx_XGIVEREF(__pyx_t_11);
            __Pyx_XGIVEREF(__pyx_t_12);
            __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
            __pyx_L16_try_end:;
          }

     16:             record[i] = numValue

          /* "cWriterow.pyx":16
     *             except TypeError:
     *                 numValue = sysmis
     *             record[i] = numValue             # <<<<<<<<<<<<<<
     *         else:
     *             value = record[i]
     */
          __pyx_t_1 = PyFloat_FromDouble(__pyx_v_numValue); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 16; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_1);
          if (__Pyx_SetItemInt(__pyx_v_record, __pyx_v_i, __pyx_t_1, sizeof(Py_ssize_t), PyInt_FromSsize_t) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 16; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          goto __pyx_L8;
        }
        /*else*/ {

     17:         else:

     18:             value = record[i]

          /* "cWriterow.pyx":18
     *             record[i] = numValue
     *         else:
     *             value = record[i]             # <<<<<<<<<<<<<<
     *             if self.ioUtf8_ and isinstance(value, unicode):
     *                 valueX = (<unicode>value).encode("utf-8")
     */
          __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_record, __pyx_v_i, sizeof(Py_ssize_t), PyInt_FromSsize_t); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_XDECREF(__pyx_v_value);
          __pyx_v_value = __pyx_t_1;
          __pyx_t_1 = 0;

     19:             if self.ioUtf8_ and isinstance(value, unicode):

          /* "cWriterow.pyx":19
     *         else:
     *             value = record[i]
     *             if self.ioUtf8_ and isinstance(value, unicode):             # <<<<<<<<<<<<<<
     *                 valueX = (<unicode>value).encode("utf-8")
     *                 strValue = valueX
     */
          __pyx_t_1 = PyObject_GetAttr(__pyx_v_self, __pyx_n_s__ioUtf8_); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 19; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_9 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 19; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (__pyx_t_9) {
            __pyx_t_1 = ((PyObject *)((PyObject*)(&PyUnicode_Type)));
            __Pyx_INCREF(__pyx_t_1);
            __pyx_t_15 = __Pyx_TypeCheck(__pyx_v_value, __pyx_t_1);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_16 = __pyx_t_15;
          } else {
            __pyx_t_16 = __pyx_t_9;
          }
          if (__pyx_t_16) {

     20:                 valueX = (<unicode>value).encode("utf-8")

            /* "cWriterow.pyx":20
     *             value = record[i]
     *             if self.ioUtf8_ and isinstance(value, unicode):
     *                 valueX = (<unicode>value).encode("utf-8")             # <<<<<<<<<<<<<<
     *                 strValue = valueX
     *             else:
     */
            if (unlikely(__pyx_v_value == Py_None)) {
              PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "encode"); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 20; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            }
            __pyx_t_1 = ((PyObject *)PyUnicode_AsUTF8String(((PyObject*)__pyx_v_value))); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 20; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(((PyObject *)__pyx_t_1));
            __Pyx_XDECREF(__pyx_v_valueX);
            __pyx_v_valueX = ((PyObject *)__pyx_t_1);
            __pyx_t_1 = 0;

     21:                 strValue = valueX

            /* "cWriterow.pyx":21
     *             if self.ioUtf8_ and isinstance(value, unicode):
     *                 valueX = (<unicode>value).encode("utf-8")
     *                 strValue = valueX             # <<<<<<<<<<<<<<
     *             else:
     *                 strValue = self.pad_8_lookup[varType] % value
     */
            __Pyx_INCREF(__pyx_v_valueX);
            __Pyx_XDECREF(__pyx_v_strValue);
            __pyx_v_strValue = __pyx_v_valueX;
            goto __pyx_L21;
          }
          /*else*/ {

     22:             else:

     23:                 strValue = self.pad_8_lookup[varType] % value

            /* "cWriterow.pyx":23
     *                 strValue = valueX
     *             else:
     *                 strValue = self.pad_8_lookup[varType] % value             # <<<<<<<<<<<<<<
     *             record[i] = strValue
     *     self.record = record
     */
            __pyx_t_1 = PyObject_GetAttr(__pyx_v_self, __pyx_n_s__pad_8_lookup); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 23; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_1, __pyx_v_varType, sizeof(int), PyInt_FromLong); if (!__pyx_t_7) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 23; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = PyNumber_Remainder(__pyx_t_7, __pyx_v_value); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 23; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_XDECREF(__pyx_v_strValue);
            __pyx_v_strValue = __pyx_t_1;
            __pyx_t_1 = 0;
          }
          __pyx_L21:;

     24:             record[i] = strValue

          /* "cWriterow.pyx":24
     *             else:
     *                 strValue = self.pad_8_lookup[varType] % value
     *             record[i] = strValue             # <<<<<<<<<<<<<<
     *     self.record = record
     */
          if (__Pyx_SetItemInt(__pyx_v_record, __pyx_v_i, __pyx_v_strValue, sizeof(Py_ssize_t), PyInt_FromSsize_t) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 24; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        __pyx_L8:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

     25:     self.record = record

      /* "cWriterow.pyx":25
     *                 strValue = self.pad_8_lookup[varType] % value
     *             record[i] = strValue
     *     self.record = record             # <<<<<<<<<<<<<<
     */
      if (PyObject_SetAttr(__pyx_v_self, __pyx_n_s__record, __pyx_v_record) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 25; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_14);
      __Pyx_AddTraceback("cWriterow.cWriterow", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_varName);
      __Pyx_XDECREF(__pyx_v_value);
      __Pyx_XDECREF(__pyx_v_valueX);
      __Pyx_XDECREF(__pyx_v_strValue);
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }